#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_LESS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_LESS_HPP_INCLUDED

#include <boost/simd/operator/include/functions/is_less.hpp>

#endif
